==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/settings.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <kconfig.h>

#include "settings.h"

void Settings::load( KConfig * config )
{
    config->setGroup( "FileIO" );
    encoding = ( Encoding ) config->readNumEntry( "Encoding", ( int ) encLaTeX );
    exportlanguage = config->readEntry( "ExportLanguage", "english" );
    exportbibliographystyle = config->readEntry( "ExportBibliographyStyle", "plain" );

    config->setGroup( "Editing" );
    enableallfields = config->readBoolEntry( "EnableAllFields", false );
    sortingColumn = config->readNumEntry( "MainListSortingColumn", -1 );
}

void Settings::save( KConfig * config )
{
    config->setGroup( "FileIO" );
    config->writeEntry( "Encoding", ( int ) encoding );
    config->writeEntry( "ExportLanguage", exportlanguage );
    config->writeEntry( "ExportBibliographyStyle", exportbibliographystyle );

    config->setGroup( "Editing" );
    config->writeEntry( "EnableAllFields", enableallfields );
    config->writeEntry( "MainListSortingColumn", sortingColumn );
}

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/settings.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <kconfig.h>

#include "settings.h"

void Settings::load( KConfig * config )
{
    // default values
    mainListColumnWidth[ 0 ] = 64;
    mainListColumnWidth[ 1 ] = 128;
    mainListColumnWidth[ 2 ] = 320;
    mainListColumnWidth[ 3 ] = 256;
    mainListColumnWidth[ 4 ] = 64;

    config->setGroup( "FileIO" );
    encoding = ( Encoding ) config->readNumEntry( "Encoding", ( int ) encLaTeX );
    exportlanguage = config->readEntry( "ExportLanguage", "english" );
    exportbibliographystyle = config->readEntry( "ExportBibliographyStyle", "plain" );

    config->setGroup( "Editing" );
    enableallfields = config->readBoolEntry( "EnableAllFields", false );
    mainListSortingColumn = config->readNumEntry( "MainListSortingColumn", -1 );
    for ( int i = 0; i < 5; i++ )
        mainListColumnWidth[ i ] = config->readNumEntry( QString( "MainListColumnWidth%1" ).arg( i ), mainListColumnWidth[ i ] );
}

void Settings::save( KConfig * config )
{
    config->setGroup( "FileIO" );
    config->writeEntry( "Encoding", ( int ) encoding );
    config->writeEntry( "ExportLanguage", exportlanguage );
    config->writeEntry( "ExportBibliographyStyle", exportbibliographystyle );

    config->setGroup( "Editing" );
    config->writeEntry( "EnableAllFields", enableallfields );
    config->writeEntry( "MainListSortingColumn", mainListSortingColumn );
    for ( int i = 0; i < 5; i++ )
        config->writeEntry( QString( "MainListColumnWidth%1" ).arg( i ), mainListColumnWidth[ i ] );
}
